Struct ShaperInstance
pub struct ShaperInstance { /* private fields */ }Expand description
An instance of a variable font.
Implementations
impl ShaperInstance
impl ShaperInstance
pub fn from_variations<V>(font: &FontRef<'_>, variations: V) -> ShaperInstance
pub fn from_variations<V>(font: &FontRef<'_>, variations: V) -> ShaperInstance
Creates a new shaper instance for the given font from the specified list of variation settings.
The setting values are in user space and the order is insignificant.
pub fn from_coords(
font: &FontRef<'_>,
coords: impl IntoIterator<Item = F2Dot14>,
) -> ShaperInstance
pub fn from_coords( font: &FontRef<'_>, coords: impl IntoIterator<Item = F2Dot14>, ) -> ShaperInstance
Creates a new shaper instance for the given font from the specified set of normalized coordinates.
The sequence of coordinates is expected to be in axis order.
pub fn from_named_instance(font: &FontRef<'_>, index: usize) -> ShaperInstance
pub fn from_named_instance(font: &FontRef<'_>, index: usize) -> ShaperInstance
Creates a new shaper instance for the given font using the variation position from the named instance at the specified index.
pub fn set_variations<V>(&mut self, font: &FontRef<'_>, variations: V)
pub fn set_variations<V>(&mut self, font: &FontRef<'_>, variations: V)
Resets the instance for the given font and variation settings.
pub fn set_coords(
&mut self,
font: &FontRef<'_>,
coords: impl IntoIterator<Item = F2Dot14>,
)
pub fn set_coords( &mut self, font: &FontRef<'_>, coords: impl IntoIterator<Item = F2Dot14>, )
Resets the instance for the given font and normalized coordinates.
pub fn set_named_instance(&mut self, font: &FontRef<'_>, index: usize)
pub fn set_named_instance(&mut self, font: &FontRef<'_>, index: usize)
Resets the instance for the given font using the variation position from the named instance at the specified index.